==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/InputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
import { InputBaseDirection_$type } from "./InputBaseDirection";
import { InputBaseSelectMode_$type } from "./InputBaseSelectMode";
/**
 * @hidden
 */
export let InputBase = /*@__PURE__*/ (() => {
    class InputBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.k = null;
            this.inputOcurred = null;
            this.focus = null;
            this.blur = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.k;
        }
        set nativeElement(a) {
            this.k = a;
            this.e.n = this.k;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get n() {
            let ret_ = this.f.m("name");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.f.u("name", value_);
        }
        get h() {
            let ret_ = this.f.m("outlined");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.u("outlined", value_);
        }
        get j() {
            let ret_ = this.f.m("required");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.u("required", value_);
        }
        get g() {
            let ret_ = this.f.m("disabled");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.u("disabled", value_);
        }
        get i() {
            let ret_ = this.f.m("readonly");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.u("readonly", value_);
        }
        get o() {
            let ret_ = this.f.m("placeholder");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.f.u("placeholder", value_);
        }
        get m() {
            let ret_ = this.f.m("label");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.f.u("label", value_);
        }
        get b() {
            let ret_ = this.f.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("size", value_);
        }
        inputOcurredChanged() {
            if (this.inputOcurred != null) {
                this.f.q("input", (a) => this.inputOcurred(this, ComponentValueChangedEventArgs.a(a)));
            }
            else {
                this.f.t("input");
            }
        }
        focusChanged() {
            if (this.focus != null) {
                this.f.q("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.t("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.f.q("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.t("blur");
            }
        }
        r() {
            this.nativeElement.connectedCallback();
        }
        y(a) {
            this.nativeElement.themeAdopted(this.f.h(a));
        }
        t(a) {
            this.nativeElement.focus(this.f.h(a));
        }
        q() {
            this.nativeElement.blur();
        }
        x(a, b, c) {
            this.nativeElement.setSelectionRange(this.f.h(a), this.f.h(b), this.f.h(enumGetBox(InputBaseDirection_$type, c)));
        }
        w(a, b, c, d) {
            this.nativeElement.setRangeText(this.f.h(a), this.f.h(b), this.f.h(c), this.f.h(enumGetBox(InputBaseSelectMode_$type, d)));
        }
    }
    InputBase.$t = /*@__PURE__*/ markType(InputBase, 'InputBase', BaseElement.$);
    return InputBase;
})();

==> igniteui-react-18.5.2-beta.0.tgz: package/esm2015/lib/InputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentValueChangedEventArgs } from "./ComponentValueChangedEventArgs";
import { VoidEventArgs } from "./VoidEventArgs";
import { InputBaseDirection_$type } from "./InputBaseDirection";
import { InputBaseSelectMode_$type } from "./InputBaseSelectMode";
/**
 * @hidden
 */
export let InputBase = /*@__PURE__*/ (() => {
    class InputBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.e = new WCNativeHelper();
            this.l = null;
            this.inputOcurred = null;
            this.focus = null;
            this.blur = null;
        }
        get f() {
            return this.e;
        }
        get nativeElement() {
            return this.l;
        }
        set nativeElement(a) {
            this.l = a;
            this.e.o = this.l;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get i() {
            let ret_ = this.f.n("outlined");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.f.v("outlined", value_);
        }
        get j() {
            let ret_ = this.f.n("readOnly");
            return ret_;
        }
        set j(a) {
            let value_ = a;
            this.f.v("readOnly", value_);
        }
        get o() {
            let ret_ = this.f.n("placeholder");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.f.v("placeholder", value_);
        }
        get n() {
            let ret_ = this.f.n("label");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.f.v("label", value_);
        }
        get b() {
            let ret_ = this.f.n("size");
            if ((ret_ === undefined && this.___rawMode)) {
                return undefined;
            }
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.camel(value_.toString());
            this.f.v("size", value_);
        }
        get g() {
            let ret_ = this.f.n("disabled");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.f.v("disabled", value_);
        }
        get k() {
            let ret_ = this.f.n("required");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.f.v("required", value_);
        }
        get h() {
            let ret_ = this.f.n("invalid");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.f.v("invalid", value_);
        }
        inputOcurredChanged() {
            if (this.inputOcurred != null) {
                this.f.r("input", (a) => this.inputOcurred(this, ComponentValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("input");
            }
        }
        focusChanged() {
            if (this.focus != null) {
                this.f.r("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.u("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.f.r("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.f.u("blur");
            }
        }
        s() {
            this.nativeElement.connectedCallback();
        }
        t() {
            this.nativeElement.disconnectedCallback();
        }
        v(a) {
            this.nativeElement.focus(this.f.i(a));
        }
        q() {
            this.nativeElement.blur();
        }
        ab(a, b, c) {
            this.nativeElement.setSelectionRange(this.f.i(a), this.f.i(b), this.f.i(enumGetBox(InputBaseDirection_$type, c)));
        }
        aa(a, b, c, d) {
            this.nativeElement.setRangeText(this.f.i(a), this.f.i(b), this.f.i(c), this.f.i(enumGetBox(InputBaseSelectMode_$type, d)));
        }
        x() {
            this.nativeElement.reportValidity();
        }
        r() {
            this.nativeElement.checkValidity();
        }
        y(a) {
            this.nativeElement.setCustomValidity(this.f.i(a));
        }
    }
    InputBase.$t = /*@__PURE__*/ markType(InputBase, 'InputBase', BaseElement.$);
    return InputBase;
})();
